# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.mcp_sub_server_binding import MCPSubServerBinding
from typing import Optional, Set
from typing_extensions import Self

class MCPServerResponse(BaseModel):
    """
    Response schema for MCP server
    """ # noqa: E501
    workspace_id: StrictStr = Field(description="Workspace ID")
    mcp_server_id: StrictStr = Field(description="MCP Server ID")
    name: StrictStr = Field(description="Name of the MCP server")
    server_configuration: List[MCPSubServerBinding] = Field(description="List of subserver bindings for the MCP server configuration")
    is_active: StrictBool = Field(description="Whether the MCP server is active")
    created_at: datetime = Field(description="Creation timestamp")
    updated_at: datetime = Field(description="Last update timestamp")
    remote_mcp_url: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["workspace_id", "mcp_server_id", "name", "server_configuration", "is_active", "created_at", "updated_at", "remote_mcp_url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MCPServerResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in server_configuration (list)
        _items = []
        if self.server_configuration:
            for _item_server_configuration in self.server_configuration:
                if _item_server_configuration:
                    _items.append(_item_server_configuration.to_dict())
            _dict['server_configuration'] = _items
        # set to None if remote_mcp_url (nullable) is None
        # and model_fields_set contains the field
        if self.remote_mcp_url is None and "remote_mcp_url" in self.model_fields_set:
            _dict['remote_mcp_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MCPServerResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "workspace_id": obj.get("workspace_id"),
            "mcp_server_id": obj.get("mcp_server_id"),
            "name": obj.get("name"),
            "server_configuration": [MCPSubServerBinding.from_dict(_item) for _item in obj["server_configuration"]] if obj.get("server_configuration") is not None else None,
            "is_active": obj.get("is_active"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "remote_mcp_url": obj.get("remote_mcp_url")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.tracking_source_response import TrackingSourceResponse

class TestTrackingSourceResponse(unittest.TestCase):
    """TrackingSourceResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TrackingSourceResponse:
        """Test TrackingSourceResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TrackingSourceResponse`
        """
        model = TrackingSourceResponse()
        if include_optional:
            return TrackingSourceResponse(
                customer_id = '',
                link_id = '',
                source_type = 'ga',
                click_id = '',
                click_id_name = 'gclid',
                utm_source = '',
                utm_medium = '',
                utm_campaign = '',
                utm_term = '',
                utm_content = '',
                utm_channel = '',
                ga = '',
                url = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                valid_until = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                event_data = [
                    flowhunt.models.tracking_event_data.TrackingEventData(
                        key = '', 
                        value_text = '', 
                        value_number = 1.337, 
                        value_boolean = True, 
                        value_datetime = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return TrackingSourceResponse(
                source_type = 'ga',
        )
        """

    def testTrackingSourceResponse(self):
        """Test TrackingSourceResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.plan_list_item_response import PlanListItemResponse

class TestPlanListItemResponse(unittest.TestCase):
    """PlanListItemResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanListItemResponse:
        """Test PlanListItemResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanListItemResponse`
        """
        model = PlanListItemResponse()
        if include_optional:
            return PlanListItemResponse(
                product_id = '',
                price_id = '',
                currency = '',
                amount_monthly = 56,
                amount_yearly = 56,
                recurring = True,
                name = '',
                description = '',
                popular = True,
                monthly_credits = 56,
                features = [
                    flowhunt.models.feature_response.FeatureResponse(
                        name = '', 
                        available = True, )
                    ],
                subscription_plan = 'S',
                self_hosted = True,
                addon = True,
                addon_type = ''
            )
        else:
            return PlanListItemResponse(
                product_id = '',
                price_id = '',
                currency = '',
                amount_monthly = 56,
                recurring = True,
                name = '',
                description = '',
                popular = True,
                monthly_credits = 56,
                features = [
                    flowhunt.models.feature_response.FeatureResponse(
                        name = '', 
                        available = True, )
                    ],
                subscription_plan = 'S',
        )
        """

    def testPlanListItemResponse(self):
        """Test PlanListItemResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.integrations_api import IntegrationsApi


class TestIntegrationsApi(unittest.TestCase):
    """IntegrationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IntegrationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_integration(self) -> None:
        """Test case for create_integration

        Create Integration
        """
        pass

    def test_customer_data_request(self) -> None:
        """Test case for customer_data_request

        Customer Data Request
        """
        pass

    def test_customer_redact(self) -> None:
        """Test case for customer_redact

        Customer Redact
        """
        pass

    def test_delete_integration(self) -> None:
        """Test case for delete_integration

        Delete Integration
        """
        pass

    def test_get_actors(self) -> None:
        """Test case for get_actors

        Get Actors
        """
        pass

    def test_get_all_integrations(self) -> None:
        """Test case for get_all_integrations

        Get All Integrations
        """
        pass

    def test_get_calendars(self) -> None:
        """Test case for get_calendars

        Get Calendars
        """
        pass

    def test_get_integration(self) -> None:
        """Test case for get_integration

        Get Integration
        """
        pass

    def test_get_picker_token(self) -> None:
        """Test case for get_picker_token

        Get Picker Token
        """
        pass

    def test_get_profile_information(self) -> None:
        """Test case for get_profile_information

        Get Profile Information
        """
        pass

    def test_get_sheets(self) -> None:
        """Test case for get_sheets

        Get Sheets
        """
        pass

    def test_get_slack_channels(self) -> None:
        """Test case for get_slack_channels

        Get Slack Channels
        """
        pass

    def test_get_slack_workspaces(self) -> None:
        """Test case for get_slack_workspaces

        Get Slack Workspaces
        """
        pass

    def test_get_wordpress_post_categories(self) -> None:
        """Test case for get_wordpress_post_categories

        Get Wordpress Post Categories
        """
        pass

    def test_get_wordpress_post_tags(self) -> None:
        """Test case for get_wordpress_post_tags

        Get Wordpress Post Tags
        """
        pass

    def test_get_wordpress_sites(self) -> None:
        """Test case for get_wordpress_sites

        Get Wordpress Sites
        """
        pass

    def test_integration_callback(self) -> None:
        """Test case for integration_callback

        Integration Callback
        """
        pass

    def test_search_integrations(self) -> None:
        """Test case for search_integrations

        Search Integrations
        """
        pass

    def test_shop_redact(self) -> None:
        """Test case for shop_redact

        Shop Redact
        """
        pass

    def test_update_admin_consent(self) -> None:
        """Test case for update_admin_consent

        Update Admin Consent
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.image_ft_response import ImageFTResponse

class TestImageFTResponse(unittest.TestCase):
    """ImageFTResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageFTResponse:
        """Test ImageFTResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageFTResponse`
        """
        model = ImageFTResponse()
        if include_optional:
            return ImageFTResponse(
                ft_type = i,
                ft_id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Fine tuning 1',
                steps = 1000,
                lora_rank = 1,
                trigger_word = 'cat',
                training_images = [https://example.com/image1, https://example.com/image2],
                status = completed,
                cover_image = ''
            )
        else:
            return ImageFTResponse(
                ft_type = i,
                ft_id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Fine tuning 1',
                steps = 1000,
                lora_rank = 1,
                trigger_word = 'cat',
                training_images = [https://example.com/image1, https://example.com/image2],
                status = completed,
                cover_image = '',
        )
        """

    def testImageFTResponse(self):
        """Test ImageFTResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BaseFoundationModel(str, Enum):
    """
    BaseFoundationModel
    """

    """
    allowed enum values
    """
    FLUX_MINUS_DEV = 'flux-dev'
    FLUX_MINUS_SCHNELL = 'flux-schnell'
    STABLE_MINUS_DIFFUSION_MINUS_3_DOT_5_MINUS_MEDIUM = 'stable-diffusion-3.5-medium'
    STABLE_MINUS_DIFFUSION_MINUS_3_DOT_5_MINUS_LARGE_MINUS_TURBO = 'stable-diffusion-3.5-large-turbo'
    STABLE_MINUS_DIFFUSION_MINUS_3_DOT_5_MINUS_LARGE = 'stable-diffusion-3.5-large'
    IMAGEN_MINUS_3 = 'imagen-3'
    IMAGEN_MINUS_3_MINUS_FAST = 'imagen-3-fast'
    IDEOGRAM_MINUS_V2 = 'ideogram-v2'
    IDEOGRAM_MINUS_V2_MINUS_TURBO = 'ideogram-v2-turbo'
    IDEOGRAM_MINUS_V2A = 'ideogram-v2a'
    IDEOGRAM_MINUS_V2A_MINUS_TURBO = 'ideogram-v2a-turbo'
    IDEOGRAM_MINUS_V3_MINUS_QUALITY = 'ideogram-v3-quality'
    IDEOGRAM_MINUS_V3_MINUS_TURBO = 'ideogram-v3-turbo'
    IDEOGRAM_MINUS_V3_MINUS_BALANCED = 'ideogram-v3-balanced'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BaseFoundationModel from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from flowhunt.models.flow_cron_status import FlowCronStatus
from typing import Optional, Set
from typing_extensions import Self

class FlowCronResponse(BaseModel):
    """
    Flow cron response.
    """ # noqa: E501
    flow_id: StrictStr
    cron_id: StrictStr
    last_run: Optional[datetime] = None
    next_run: Optional[datetime] = None
    status: FlowCronStatus
    input_text: Optional[StrictStr] = None
    interval_settings: StrictStr
    variables: Optional[Dict[str, Any]] = None
    cron_name: StrictStr
    __properties: ClassVar[List[str]] = ["flow_id", "cron_id", "last_run", "next_run", "status", "input_text", "interval_settings", "variables", "cron_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FlowCronResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if last_run (nullable) is None
        # and model_fields_set contains the field
        if self.last_run is None and "last_run" in self.model_fields_set:
            _dict['last_run'] = None

        # set to None if next_run (nullable) is None
        # and model_fields_set contains the field
        if self.next_run is None and "next_run" in self.model_fields_set:
            _dict['next_run'] = None

        # set to None if input_text (nullable) is None
        # and model_fields_set contains the field
        if self.input_text is None and "input_text" in self.model_fields_set:
            _dict['input_text'] = None

        # set to None if variables (nullable) is None
        # and model_fields_set contains the field
        if self.variables is None and "variables" in self.model_fields_set:
            _dict['variables'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FlowCronResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "flow_id": obj.get("flow_id"),
            "cron_id": obj.get("cron_id"),
            "last_run": obj.get("last_run"),
            "next_run": obj.get("next_run"),
            "status": obj.get("status"),
            "input_text": obj.get("input_text"),
            "interval_settings": obj.get("interval_settings"),
            "variables": obj.get("variables"),
            "cron_name": obj.get("cron_name")
        })
        return _obj





# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.tracking_api import TrackingApi


class TestTrackingApi(unittest.TestCase):
    """TrackingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TrackingApi()

    def tearDown(self) -> None:
        pass

    def test_search_events(self) -> None:
        """Test case for search_events

        Search Events
        """
        pass

    def test_search_links(self) -> None:
        """Test case for search_links

        Search Links
        """
        pass

    def test_search_sources(self) -> None:
        """Test case for search_sources

        Search Sources
        """
        pass

    def test_track_click(self) -> None:
        """Test case for track_click

        Track Click
        """
        pass

    def test_track_event(self) -> None:
        """Test case for track_event

        Track Event
        """
        pass

    def test_track_link(self) -> None:
        """Test case for track_link

        Track Link
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.flow_detail_response import FlowDetailResponse

class TestFlowDetailResponse(unittest.TestCase):
    """FlowDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowDetailResponse:
        """Test FlowDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowDetailResponse`
        """
        model = FlowDetailResponse()
        if include_optional:
            return FlowDetailResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                detailed_description = '',
                config = flowhunt.models.flow_config.FlowConfig(
                    nodes = [
                        null
                        ], 
                    edges = [
                        null
                        ], ),
                flow_type = p,
                executed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                category_id = '',
                branch = 'P',
                enable_cache = True,
                draft_version_nr = 56,
                prod_version_nr = 56,
                last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return FlowDetailResponse(
                id = '123e4567-e89b-12d3-a456-426614174000',
                name = 'Flow 1',
                description = 'Flow 1 description',
                config = flowhunt.models.flow_config.FlowConfig(
                    nodes = [
                        null
                        ], 
                    edges = [
                        null
                        ], ),
                flow_type = p,
                branch = 'P',
                enable_cache = True,
        )
        """

    def testFlowDetailResponse(self):
        """Test FlowDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.models.image_inference_request import ImageInferenceRequest

class TestImageInferenceRequest(unittest.TestCase):
    """ImageInferenceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageInferenceRequest:
        """Test ImageInferenceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ImageInferenceRequest`
        """
        model = ImageInferenceRequest()
        if include_optional:
            return ImageInferenceRequest(
                base_model = 'flux-dev',
                prompt = '',
                image_fts = [
                    ''
                    ],
                number_of_outputs = 56,
                aspect_ratio = '1:1',
                steps = 56,
                guidance_scale = 0.0,
                styles = [
                    ''
                    ],
                effects = [
                    ''
                    ],
                use_ai_agent = True
            )
        else:
            return ImageInferenceRequest(
                base_model = 'flux-dev',
                prompt = '',
                image_fts = [
                    ''
                    ],
        )
        """

    def testImageInferenceRequest(self):
        """Test ImageInferenceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    FlowHunt

    FlowHunt API

    The version of the OpenAPI document: 2.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from flowhunt.api.mcp_servers_api import MCPServersApi


class TestMCPServersApi(unittest.TestCase):
    """MCPServersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MCPServersApi()

    def tearDown(self) -> None:
        pass

    def test_create_mcp_server(self) -> None:
        """Test case for create_mcp_server

        Create Mcp Server
        """
        pass

    def test_delete_mcp_server(self) -> None:
        """Test case for delete_mcp_server

        Delete Mcp Server
        """
        pass

    def test_get_all_mcp_subservers(self) -> None:
        """Test case for get_all_mcp_subservers

        Get All Mcp Subservers
        """
        pass

    def test_get_mcp_server(self) -> None:
        """Test case for get_mcp_server

        Get Mcp Server
        """
        pass

    def test_search_mcp_servers(self) -> None:
        """Test case for search_mcp_servers

        Search Mcp Servers
        """
        pass

    def test_update_mcp_server(self) -> None:
        """Test case for update_mcp_server

        Update Mcp Server
        """
        pass


if __name__ == '__main__':
    unittest.main()
